<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    Pinpoint
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function pinpoint_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
	}
}
add_action( 'wp_head', 'pinpoint_pingback_header' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function pinpoint_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Adds a classes for home page.
	if ( is_home() ) {
		$classes[] = 'home-container';
	}

	// Adds a classes for post and page.
	if ( is_singular() ) {
		$classes[] = 'is-page is-post';
	}

	// Adds a class if comment open.
	if ( comments_open() ) {
		$classes[] = 'has-comments';
	}

	return $classes;
}
add_filter( 'body_class', 'pinpoint_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function pinpoint_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	// Adds a classes on home and archive page.
	if ( is_home() || is_archive() || is_search() ) {
		$classes[] = 'thumb grid-item';
	}

	if ( has_post_format( 'image' ) ) {
		$classes[] = 'thumbtype-photo';
	} elseif ( has_post_format( 'quote' ) ) {
		$classes[] = 'thumbtype-quote';
	} elseif ( has_post_format( 'audio' ) ) {
		$classes[] = 'thumbtype-audio';
	} elseif ( has_post_format( 'video' ) ) {
		$classes[] = 'thumbtype-video';
	} elseif ( has_post_format( 'link' ) ) {
		$classes[] = 'thumbtype-link';
	} elseif ( has_post_format( 'chat' ) ) {
		$classes[] = 'thumbtype-chat';
	} else {
		$classes[] = 'thumbtype-text';
	}

	// Replace hentry class with entry.
	$classes[] = 'entry';

	return $classes;
}
add_filter( 'post_class', 'pinpoint_post_classes' );

/**
 * Remove 'hentry' from post_class()
 */
function pinpoint_remove_hentry( $class ) {
	$class = array_diff( $class, array( 'hentry' ) );
	return $class;
}
add_filter( 'post_class', 'pinpoint_remove_hentry' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function pinpoint_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'pinpoint_excerpt_more' );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function pinpoint_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'pinpoint_page_sidebar_plugin' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function pinpoint_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'pinpoint' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'pinpoint' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'pinpoint' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'pinpoint' );
	$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'pinpoint' );
	$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'pinpoint' );
	$contactmethods['dribbble']    = esc_html__( 'Dribbble URL', 'pinpoint' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'pinpoint_contact_info_fields' );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function pinpoint_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'pinpoint_extend_archive_title' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function pinpoint_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'pinpoint_customize_tag_cloud' );
